@@ -2,7 +2,10 @@ mod filter;
 mod icon;
 mod identifier;
 mod interface_parameter_type;
+mod job;
+mod job_progression;
 mod job_status;
+mod jobs_status;
 mod list_item;
 mod media_segment;
 mod parameter;
@@ -21,7 +24,10 @@ pub use filter::Filter;
 pub use icon::Icon;
 pub use identifier::Identifier;
 pub use interface_parameter_type::InterfaceParameterType;
-pub use job_status::JobsStatus;
+pub use job::Job;
+pub use job_progression::JobProgression;
+pub use job_status::JobStatus;
+pub use jobs_status::JobsStatus;
 pub use list_item::ListItem;
 pub use media_segment::MediaSegment;
 pub use parameter::Parameter;
