@@ -1,4 +1,4 @@
-use crate::common::{StartParameter, Step};
+use crate::common::{Job, StartParameter, Step};
 use chrono::NaiveDateTime;
 use serde::{Deserialize, Serialize};
 
@@ -30,6 +30,9 @@ pub struct Workflow {
   /// List of steps
   #[serde(default)]
   pub steps: Vec<Step>,
+  /// List of jobs
+  #[serde(default)]
+  pub jobs: Vec<Job>,
   /// List of tags to classify the workflow
   #[serde(default, skip_serializing_if = "Vec::is_empty")]
   pub tags: Vec<String>,
